@@ -7,7 +7,7 @@ use 5.008;
 
 use vars qw($VERSION);
 
-$VERSION = '0.3.1';
+$VERSION = '0.3.2';
 
 package HTML::Latemp::GenMakeHelpers::Base;
 
@@ -70,38 +70,6 @@ sub initialize
 
 package HTML::Latemp::GenMakeHelpers;
 
-=head1 NAME
-
-HTML::Latemp::GenMakeHelpers - A Latemp Utility Module.
-
-=head1 SYNOPSIS
-
-    use HTML::Latemp::GenMakeHelpers;
-
-    my $generator =
-        HTML::Latemp::GenMakeHelpers->new(
-            'hosts' =>
-            [ map {
-                +{ 'id' => $_, 'source_dir' => $_,
-                    'dest_dir' => "\$(ALL_DEST_BASE)/$_-homepage"
-                }
-            } (qw(common t2 vipe)) ],
-        );
-
-    $generator->process_all();
-
-=head1 API METHODS
-
-=head2 my $generator = HTML::Latemp::GenMakeHelpers->new('hosts => [@hosts])
-
-Construct an object with the host defined in @hosts.
-
-=head2 $generator->process_all()
-
-Process all hosts.
-
-=head1 INTERNAL METHODS
-=cut
 
 
 use vars qw(@ISA);
@@ -113,12 +81,6 @@ use File::Basename;
 
 __PACKAGE__->mk_accessors(qw(base_dir _common_buckets hosts hosts_id_map));
 
-=head2 initialize()
-
-Called by the constructor to initialize the object. Can be sub-classes by
-derived classes.
-
-=cut
 
 sub initialize
 {
@@ -178,11 +140,6 @@ sub _make_path
 }
 
 
-=head2 $generator->get_initial_buckets($host)
-
-Get the initial buckets for the host $host.
-
-=cut
 
 sub get_initial_buckets
 {
@@ -253,11 +210,6 @@ sub _process_bucket
         };
 }
 
-=head2 $generator->get_buckets($host)
-
-Get the processed buckets.
-
-=cut
 
 sub get_buckets
 {
@@ -298,11 +250,6 @@ sub _sort_files
     return [ sort { $a cmp $b } @$files_ref ];
 }
 
-=head2 $self->get_non_bucketed_files($host)
-
-Get the files that were not placed in any bucket.
-
-=cut
 
 sub get_non_bucketed_files
 {
@@ -320,11 +267,6 @@ sub get_non_bucketed_files
     return $self->_sort_files($host, $files);
 }
 
-=head2 $self->place_files_into_buckets($host, $files, $buckets)
-
-Sort the files into the buckets.
-
-=cut
 
 sub place_files_into_buckets
 {
@@ -366,11 +308,6 @@ sub place_files_into_buckets
     }
 }
 
-=head2 $self->get_rules_template($host)
-
-Get the makefile rules template for the host $host.
-
-=cut
 
 sub get_rules_template
 {
@@ -442,11 +379,6 @@ X8X_COMMON_DOCS_DEST = \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_DOCS))
 EOF
 }
 
-=head2 $self->process_host($host)
-
-Process the host $host.
-
-=cut
 
 sub process_host
 {
@@ -492,6 +424,75 @@ sub process_host
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::Latemp::GenMakeHelpers - A Latemp Utility Module.
+
+=head1 VERSION
+
+version 0.3.2
+
+=head1 SYNOPSIS
+
+    use HTML::Latemp::GenMakeHelpers;
+
+    my $generator =
+        HTML::Latemp::GenMakeHelpers->new(
+            'hosts' =>
+            [ map {
+                +{ 'id' => $_, 'source_dir' => $_,
+                    'dest_dir' => "\$(ALL_DEST_BASE)/$_-homepage"
+                }
+            } (qw(common t2 vipe)) ],
+        );
+
+    $generator->process_all();
+
+=head1 API METHODS
+
+=head2 my $generator = HTML::Latemp::GenMakeHelpers->new('hosts => [@hosts])
+
+Construct an object with the host defined in @hosts.
+
+=head2 $generator->process_all()
+
+Process all hosts.
+
+=head1 INTERNAL METHODS
+
+=head2 initialize()
+
+Called by the constructor to initialize the object. Can be sub-classes by
+derived classes.
+
+=head2 $generator->get_initial_buckets($host)
+
+Get the initial buckets for the host $host.
+
+=head2 $generator->get_buckets($host)
+
+Get the processed buckets.
+
+=head2 $self->get_non_bucketed_files($host)
+
+Get the files that were not placed in any bucket.
+
+=head2 $self->place_files_into_buckets($host, $files, $buckets)
+
+Sort the files into the buckets.
+
+=head2 $self->get_rules_template($host)
+
+Get the makefile rules template for the host $host.
+
+=head2 $self->process_host($host)
+
+Process the host $host.
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif@iglu.org.il> >>
@@ -513,5 +514,141 @@ Copyright 2005 Shlomi Fish, All Rights Reserved.
 This program is free software; you can redistribute it and/or modify it
 under the MIT X11 License.
 
-=cut
+=head1 AUTHOR
 
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2005 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-GenMakeHelpers or by
+email to bug-html-latemp-genmakehelpers@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc HTML::Latemp::GenMakeHelpers
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/H/HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=HTML-Latemp-GenMakeHelpers>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=HTML::Latemp::GenMakeHelpers>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-html-latemp-genmakehelpers at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-GenMakeHelpers>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<http://bitbucket.org/shlomif/latemp>
+
+  hg clone ssh://hg@bitbucket.org/shlomif/latemp
+
+=cut
